@@ -19,15 +19,15 @@ file_extension = 'txt'
 
 class Writer(BackendBase):
     symbols = {
-        'ndash': '-',
-        'newblock': ' ',
-        'nbsp': ' '
+        'ndash': u'-',
+        'newblock': u' ',
+        'nbsp': u' '
     }
     
     def format_tag(self, tag_name, text):
         return text
     
     def write_entry(self, key, label, text):
-        self.output("[%s] " % label)
+        self.output(u"[%s] " % label)
         self.output(text)
-        self.output('\n')
+        self.output(u'\n')
