@@ -17,14 +17,20 @@ from __future__ import with_statement
 
 import pybtex.io
 
-class WriterBase:
-    def __init__(self, encoding = None):
-        if not encoding:
-            encoding = pybtex.io.get_default_encoding()
+
+available_plugins = ('bibtex', 'bibtexml', 'bibyaml')
+
+
+class WriterBase(object):
+    unicode_io = False
+
+    def __init__(self, encoding=None):
         self.encoding = encoding
 
     def write_file(self, bib_data, filename):
-        with pybtex.io.open_plain(filename, 'w') as stream:
+        open_file = pybtex.io.open_unicode if self.unicode_io else pybtex.io.open_raw
+        mode = 'w' if self.unicode_io else 'wb'
+        with open_file(filename, mode, encoding=self.encoding) as stream:
             self.write_stream(bib_data, stream)
 
     def write_stream(self, bib_data, stream):
